.. _plotting:

===========================================
Pretty plots with :mod:`~psychopy_ext.plot`
===========================================


*Basic philosophy: Plots must come out pretty by default (no effort from the user), not after hours of tweaking.*

For a while, ``psychopy_ext`` offered pretty plotting functionality. It has now been deprecated in favor of `seaborn`, and will continue to build upon it.


Continue to :ref:`models`.
